summaryrefslogtreecommitdiff
path: root/telepathy-glib/client-channel-factory.c
diff options
context:
space:
mode:
authorGuillaume Desmottes <guillaume.desmottes@collabora.co.uk>2010-10-21 15:21:01 +0200
committerGuillaume Desmottes <guillaume.desmottes@collabora.co.uk>2010-10-21 15:21:01 +0200
commitcddac481f008f7ff90154b84992a137106f72ef9 (patch)
treece78502a1495a1008477eed9a8b0aa3582b21529 /telepathy-glib/client-channel-factory.c
parenta408205d4caa51b147386ee8e3e9338d755bac7a (diff)
downloadtelepathy-glib-cddac481f008f7ff90154b84992a137106f72ef9.tar.gz
rename get_channel_features_ to dup_
Diffstat (limited to 'telepathy-glib/client-channel-factory.c')
-rw-r--r--telepathy-glib/client-channel-factory.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/telepathy-glib/client-channel-factory.c b/telepathy-glib/client-channel-factory.c
index 290c27e75..25b8eb949 100644
--- a/telepathy-glib/client-channel-factory.c
+++ b/telepathy-glib/client-channel-factory.c
@@ -30,7 +30,7 @@
* Once a channel has been created by a factory using
* tp_client_channel_factory_create_channel(), the caller should then prepare
* on it the channel features returned by
- * tp_client_channel_factory_get_channel_features() using
+ * tp_client_channel_factory_dup_channel_features() using
* tp_proxy_prepare_async().
*
* Since: 0.13.2
@@ -40,7 +40,7 @@
* TpClientChannelFactoryInterface:
* @parent: the parent
* @create_channel: the function used to create channels
* @get_channel_features: channel features that have to be prepared on
* newly created channels
*
* Interface for a channel factory
@@ -100,7 +100,7 @@ tp_client_channel_factory_create_channel (TpClientChannelFactoryInterface *self,
}
/**
- * tp_client_channel_factory_get_channel_features:
+ * tp_client_channel_factory_dup_channel_features:
* @self: a client channel factory
* @channel: a #TpChannel
*
@@ -112,7 +112,7 @@ tp_client_channel_factory_create_channel (TpClientChannelFactoryInterface *self,
* Since: 0.13.UNRELEASED
*/
GArray *
-tp_client_channel_factory_get_channel_features (
+tp_client_channel_factory_dup_channel_features (
TpClientChannelFactoryInterface *self,
TpChannel *channel)
{
@@ -123,8 +123,8 @@ tp_client_channel_factory_get_channel_features (
g_return_val_if_fail (TP_IS_CHANNEL (channel), NULL);
- if (iface->get_channel_features != NULL)
- return iface->get_channel_features (iface, channel);
+ if (iface->dup_channel_features != NULL)
+ return iface->dup_channel_features (iface, channel);
arr = g_array_sized_new (FALSE, FALSE, sizeof (GQuark), 1);
@@ -40,7 +40,7 @@
* @parent: the parent
* @create_channel: the function used to create channels
- * @get_channel_features: channel features that have to be prepared on
+ * @dup_channel_features: channel features that have to be prepared on
* newly created channels
*